#
# SchoolTool - common information systems platform for school administration
# Copyright (c) 2012 Shuttleworth Foundation,
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License along
# with this program; if not, write to the Free Software Foundation, Inc.,
# 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
#
"""
SchoolTool Quiz assignments.
"""

from persistent import Persistent
from zope.annotation.interfaces import IAnnotations
from zope.container.btree import BTreeContainer
from zope.container.contained import Contained 
from zope.interface import implements

from schooltool.quiz import interfaces

from zope.location import location
from zope.proxy import removeAllProxies

ASSIGNMENTS_KEY = "schooltool.quiz.assignments"

class Assignments(BTreeContainer):
    implements(interfaces.IAssignments)

    def addAssignment(self, assignment):
        self[assignment.item.__name__] = assignment


class Assignment(Persistent, Contained):
    
    implements(interfaces.IAssignment)

    def __init__(self, item):
        Contained.__init__(self)
        self.item = item
 

def getAssignments(context):
    #This is a method copied from the IEvaluations process. 
    #Adapts IHaveAssignments to Assignments
    annotations = IAnnotations(context)
    try:
        return annotations[ASSIGNMENTS_KEY]
    except KeyError:
        assignments = Assignments()
        annotations[ASSIGNMENTS_KEY] = assignments
        location.locate(assignments, removeAllProxies(context),
                        '++assignments++')
        return assignments
getAssignments.factory = Assignments
