#
# SchoolTool - common information systems platform for school administration
# Copyright (c) 2012 Shuttleworth Foundation,
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License along
# with this program; if not, write to the Free Software Foundation, Inc.,
# 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
#
"""
SchoolTool Quiz preferences views.
"""

from zope.browserpage.viewpagetemplatefile import ViewPageTemplateFile
from zope.interface import implements
from zope.traversing.browser.absoluteurl import absoluteURL

from z3c.form import form, field, button

from schooltool.skin import flourish

from schooltool.quiz import interfaces
from schooltool.quiz import QuizMessage as _
from schooltool.quiz.preferences import Rule
from schooltool.cando.skill import querySkillScoreSystem

from zope.component import adapts
from zope.interface import Interface
from z3c.form.interfaces import IObjectWidget
from z3c.form.object import ObjectSubForm
from z3c.form.object import SubformAdapter
from z3c.form.object import registerFactoryAdapter
from z3c.form import validator
from zope.schema import ValidationError

registerFactoryAdapter(interfaces.IRule,Rule)

class OutOfRangeError(ValidationError):
    
    __doc__ = _("Choice is out of range")

class DuplicateRuleError(ValidationError):
    
    __doc__ = _("You can't apply more than one rule to any level")

class RuleValidator(validator.SimpleFieldValidator):
    
    def validate(self, value, force=False):
        super(RuleValidator, self).validate(value, force)
        skillscoresystem = querySkillScoreSystem().scoresDict
        if skillscoresystem[min(skillscoresystem.keys())] >= value or\
           value >= skillscoresystem[max(skillscoresystem.keys())] :
            raise OutOfRangeError(value)
            

class RuleSetValidator(validator.SimpleFieldValidator):
    
    def validate(self, value, force=False):
        super(RuleSetValidator, self).validate(value, force)
        levels = [rule.level for rule in value]
        skillscoresystem = querySkillScoreSystem().scoresDict
        minlevel = skillscoresystem[min(skillscoresystem.keys())]
        maxlevel = skillscoresystem[max(skillscoresystem.keys())]
        for level in levels:
            if level < minlevel or level > maxlevel:
                raise OutOfRangeError(level)
            if levels.count(level) > 1:
                raise DuplicateRuleError(value)

class RuleSubForm(ObjectSubForm):

    pass

class RuleSubformAdapter(SubformAdapter):

    adapts(Interface,
           flourish.IFlourishLayer,
           Interface,
           Interface,
           IObjectWidget,
           Interface,
           Interface)

    factory = RuleSubForm

class ApplicationPreferencesEditView(flourish.form.Form, form.EditForm):

    implements(interfaces.ISchoolToolQuizView)

    container_class = 'container widecontainer'
    legend = _('Preferences Information')
    fields = field.Fields(interfaces.IApplicationPreferences)
    content_template = ViewPageTemplateFile('templates/form.pt')

    def update(self):
        return form.EditForm.update(self)

    def updateActions(self):
        super(ApplicationPreferencesEditView, self).updateActions()
        self.actions['submit'].addClass('button-ok')
        self.actions['cancel'].addClass('button-cancel')

    def nextURL(self):
        return '%s/manage' % absoluteURL(self.context, self.request)

    @button.buttonAndHandler(_('Submit'), name='submit')
    def handle_submit(self, action):
        super(ApplicationPreferencesEditView,
              self).handleApply.func(self, action)
        if (self.status == self.successMessage or
            self.status == self.noChangesMessage):
            self.request.response.redirect(self.nextURL())

    @button.buttonAndHandler(_('Cancel'), name='cancel')
    def handle_cancel(self, action):
        self.request.response.redirect(self.nextURL())

validator.WidgetValidatorDiscriminators(
    RuleSetValidator, 
    view = ApplicationPreferencesEditView,
    field = interfaces.IApplicationPreferences['skill_rules'],
    )


validator.WidgetValidatorDiscriminators(
    RuleValidator, 
    view = ApplicationPreferencesEditView,
    field = interfaces.IRule['level'],
    )
