#
# SchoolTool - common information systems platform for school administration
# Copyright (c) 2012 Shuttleworth Foundation
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
#
"""
Functional selenium tests for schooltool.quiz
"""

import unittest

from schooltool.testing.selenium import collect_ftests

from schooltool.quiz.stesting import quiz_selenium_layer


choice_sels = {
    'remove': 'form-widgets-choices-%d-remove',
    'body': 'form-widgets-choices-%d-widgets-body',
    'correct': 'form-widgets-choices-%d-widgets-correct-0',
    }


def print_tabs(browser):
    for li in browser.query_all.css('ul.navigation li'):
        text = li.query.tag('a').text
        if 'active' in li.get_attribute('class'):
            text = '*%s*' % text
        print text


def add_choices(browser, choices):
    sel = 'form-widgets-choices-buttons-add'
    for i, choice in enumerate(choices):
        body, correct = choice
        browser.query.id(sel).click()
        browser.query.id(choice_sels['body'] % i).ui.set_value(body)
        if correct:
            browser.query.id(choice_sels['correct'] % i).click()


def fill_question_form(browser, type_, body, choices=[], solution=''):
    sel = '//span[@class="label" and text()="%s"]' % type_
    browser.query.xpath(sel).click()
    browser.query.id('form-widgets-body').ui.set_value(body)
    if type_ == 'Open':
        sel = 'form-widgets-solution'
        browser.query.id(sel).ui.set_value(solution)
    else:
        add_choices(browser, choices)


def print_quiz_item_bodies(browser):
    sel = '.quiz-items-table tbody tr'
    for row in browser.query_all.css(sel):
        print row.query.css('.restructuredtext-widget')


def print_quiz_item_types(browser):
    sel = '.quiz-items-table tbody tr td:nth-child(3)'
    for cell in browser.query_all.css(sel):
        print cell.text


def test_suite():
    extra_globs = {
        'print_tabs': print_tabs,
        'add_choices': add_choices,
        'fill_question_form': fill_question_form,
        'print_quiz_item_bodies': print_quiz_item_bodies,
        'print_quiz_item_types': print_quiz_item_types,
        }
    return collect_ftests(layer=quiz_selenium_layer,
                          extra_globs=extra_globs)


if __name__ == '__main__':
    unittest.main(defaultTest='test_suite')
