#
# SchoolTool - common information systems platform for school administration
# Copyright (c) 2012 Shuttleworth Foundation,
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License along
# with this program; if not, write to the Free Software Foundation, Inc.,
# 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
#
"""
SchoolTool Quiz deployedquiz.
"""

from persistent import Persistent
from persistent.list import PersistentList
from zope.annotation.interfaces import IAnnotations
from zope.component import adapter
from zope.container.btree import BTreeContainer
from zope.container.contained import Contained, containedEvent
from zope.event import notify
from zope.interface import implements, implementer

from schooltool.app.interfaces import ISchoolToolApplication
from schooltool.course.interfaces import ISection
from schooltool.relationship import RelationshipProperty

from schooltool.quiz import interfaces
from schooltool.quiz import relationships


SECTION_DEPLOYEDQUIZCONTAINER_KEY = 'schooltool.quiz.quiz'


class DeployedQuizContainer(BTreeContainer):

    implements(interfaces.IDeployedQuizContainer)


class DeployedQuiz(Persistent, Contained):

    implements(interfaces.IDeployedQuiz)

    title = None
    random = None
    start = None
    end = None
    open_by_teacher = None
    worksheet_id = None
    activity_id = None
    period_id = None
    order = None

    quizzes = RelationshipProperty(relationships.URIQuizDeployedQuizzes,
                                   relationships.URIDeployedQuiz,
                                   relationships.URIQuiz)

    items = RelationshipProperty(relationships.URIDeployedQuizItems,
                                 relationships.URIDeployedQuiz,
                                 relationships.URIQuizItem)

    def __init__(self):
        super(DeployedQuiz, self).__init__()
        self.order = PersistentList()

    def __iter__(self):
        app = ISchoolToolApplication(None)
        item_container = interfaces.IQuizItemContainer(app)
        return iter([item_container[item_id] for item_id in self.order])


@adapter(ISection)
@implementer(interfaces.IDeployedQuizContainer)
def getSectionDeployedQuizContainer(section):
    annotations = IAnnotations(section)
    try:
        return annotations[SECTION_DEPLOYEDQUIZCONTAINER_KEY]
    except (KeyError,):
        container = DeployedQuizContainer()
        annotations[SECTION_DEPLOYEDQUIZCONTAINER_KEY] = container
        container, event = containedEvent(container, section, 'quizzes')
        notify(event)
        return container
getSectionDeployedQuizContainer.factory = DeployedQuizContainer


@adapter(interfaces.IDeployedQuizContainer)
@implementer(ISection)
def getDeployedQuizContainerSection(container):
    return container.__parent__


@adapter(interfaces.IDeployedQuiz)
@implementer(ISection)
def getDeployedQuizSection(deployed):
    container = deployed.__parent__
    return ISection(container)


