#
# SchoolTool - common information systems platform for school administration
# Copyright (c) 2012 Shuttleworth Foundation
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
#
"""
Evolve database to generation 1.

Set created/modified datetimes on Quiz and QuizItem objects
"""

from datetime import datetime
import pytz

from zope.app.generations.utility import findObjectsProviding, getRootFolder
from zope.dublincore.interfaces import IZopeDublinCore
from zope.component.hooks import getSite, setSite

from schooltool.app.interfaces import ISchoolToolApplication

from schooltool.quiz.quiz import APP_QUIZCONTAINER_KEY
from schooltool.quiz.quizitem import APP_QUIZITEMCONTAINER_KEY


def evolve(context):
    root = getRootFolder(context)
    old_site = getSite()
    apps = findObjectsProviding(root, ISchoolToolApplication)
    for app in apps:
        setSite(app)
        for key in [APP_QUIZCONTAINER_KEY, APP_QUIZITEMCONTAINER_KEY]:
            container = app.get(key)
            if container:
                for value in container.values():
                    dc = IZopeDublinCore(value)
                    created = dc.created
                    modified = dc.modified
                    if created is None:
                        mtime = datetime.fromtimestamp(value._p_mtime)
                        created = datetime(
                            mtime.year, mtime.month, mtime.day,
                            mtime.hour, mtime.minute, mtime.second,
                            tzinfo=pytz.utc)
                        dc.created = created
                    if modified is None:
                        dc.modified = created
    setSite(old_site)
