#
# SchoolTool - common information systems platform for school administration
# Copyright (c) 2012 Shuttleworth Foundation
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
#
"""
Evolve database to generation 2.

Set order attribute for Quiz/DeployedQuiz objects
"""

from persistent.list import PersistentList

from zope.app.generations.utility import findObjectsProviding, getRootFolder

from schooltool.course.interfaces import ISection

from schooltool.quiz import interfaces


def evolve(context):
    root = getRootFolder(context)
    for quiz in findObjectsProviding(root, interfaces.IQuiz):
        if quiz.order is None:
            quiz.order = PersistentList()
            for item in quiz.items:
                quiz.order.append(item.__name__)
    for section in findObjectsProviding(root, ISection):
        container = interfaces.IDeployedQuizContainer(section)
        for deployed in container.values():
            if deployed.order is None:
                deployed.order = PersistentList()
                for item in deployed.items:
                    deployed.order.append(item.__name__)
