#
# SchoolTool - common information systems platform for school administration
# Copyright (c) 2012 Shuttleworth Foundation
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
#
"""
Evolve database to generation 3.

Set evaluator to None by default for skill evaluations
"""

from persistent.list import PersistentList

from zope.app.generations.utility import findObjectsProviding, getRootFolder
from schooltool.app.interfaces import ISchoolToolApplication
from schooltool.course.interfaces import ISectionContainer
from schooltool.cando.interfaces import ISectionSkills, ISkillsGradebook
from schooltool.requirement.interfaces import IEvaluations


from schooltool.quiz import interfaces


def evolve(context):
    root = getRootFolder(context)
    sections = findObjectsProviding(root, ISectionContainer)
    for sectioncontainer in sections:
        for section in sectioncontainer.values():
            memberlist = [member for member in section.members]
            skillsets = ISectionSkills(section)
            for skillset in skillsets.values():
                gradebook = ISkillsGradebook(skillset)
                for skill in skillset.values():
                    for student in memberlist:
                        evaluations = IEvaluations(student)
                        current_score =  gradebook.getScore(student, skill)
                        if current_score:
                            evaluations[skill].evaluator = None
            
