#
# SchoolTool - common information systems platform for school administration
# Copyright (c) 2012 Shuttleworth Foundation
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
#
"""
Evolve database to generation 4.

Make image urls to use APP_ROOT_PATTERN and make sure the image is
linked to the question
"""

from urlparse import urlparse

from zope.app.generations.utility import findObjectsProviding, getRootFolder
from zope.component.hooks import getSite, setSite

from schooltool.app.interfaces import ISchoolToolApplication

from schooltool.quiz import interfaces
from schooltool.quiz.utils import APP_ROOT_PATTERN


image_directive = '.. image::'


def evolve(context):
    root = getRootFolder(context)
    old_site = getSite()
    apps = findObjectsProviding(root, ISchoolToolApplication)
    for app in apps:
        setSite(app)
        questions = interfaces.IQuizItemContainer(app)
        images = interfaces.IQuizImageContainer(app)
        for question in questions.values():
            if image_directive in question.body:
                new_body = None
                path = None
                for line in question.body.splitlines():
                    if image_directive in line:
                        url = line.split(image_directive)[-1].strip()
                        path = urlparse(url).path
                        new_url = '%s%s' % (APP_ROOT_PATTERN, path)
                        new_body = question.body.replace(url, new_url)
                if new_body is not None:
                    question.body = new_body
                name = path.split('quiz_images/')[-1].split('/inline')[0]
                image = images[name]
                if image not in question.images:
                    question.images.add(image)
    setSite(old_site)
