#
# SchoolTool - common information systems platform for school administration
# Copyright (c) 2012 Shuttleworth Foundation,
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License along
# with this program; if not, write to the Free Software Foundation, Inc.,
# 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
#
"""
SchoolTool Quiz quiz.
"""

from persistent import Persistent
from persistent.list import PersistentList
from zope.component import adapter
from zope.container.btree import BTreeContainer
from zope.container.contained import Contained
from zope.container.interfaces import INameChooser
from zope.interface import implements, implementer

from schooltool.app.app import InitBase, StartUpBase
from schooltool.app.interfaces import ISchoolToolApplication
from schooltool.relationship import RelationshipProperty

from schooltool.quiz import interfaces
from schooltool.quiz import relationships


APP_QUIZCONTAINER_KEY = 'schooltool.quiz.quiz'


class QuizContainer(BTreeContainer):

    implements(interfaces.IQuizContainer)


class Quiz(Persistent, Contained):

    implements(interfaces.IQuiz)

    title = None
    order = None

    items = RelationshipProperty(relationships.URIQuizItems,
                                 relationships.URIQuiz,
                                 relationships.URIQuizItem)

    editors = RelationshipProperty(relationships.URIQuizEditors,
                                   relationships.URIQuiz,
                                   relationships.URIQuizEditor)

    deployed = RelationshipProperty(relationships.URIQuizDeployedQuizzes,
                                    relationships.URIQuiz,
                                    relationships.URIDeployedQuiz)

    def __init__(self):
        super(Quiz, self).__init__()
        self.order = PersistentList()

    def copy(self):
        result = Quiz()
        result.title = self.title
        app = ISchoolToolApplication(None)
        item_container = interfaces.IQuizItemContainer(app)
        chooser = INameChooser(item_container)
        for item in self:
            copy = item.copy()
            name = chooser.chooseName('', copy)
            item_container[name] = copy
            result.items.add(copy)
            result.order.append(name)
        return result

    def updateOrder(self, item_id, position):
        self.order.remove(item_id)
        self.order.insert(position, item_id)

    def __iter__(self):
        app = ISchoolToolApplication(None)
        item_container = interfaces.IQuizItemContainer(app)
        return iter([item_container[item_id] for item_id in self.order])


class QuizContainerInit(InitBase):

    def __call__(self):
        self.app[APP_QUIZCONTAINER_KEY] = QuizContainer()


class QuizContainerAppStartup(StartUpBase):

    def __call__(self):
        if APP_QUIZCONTAINER_KEY not in self.app:
            self.app[APP_QUIZCONTAINER_KEY] = QuizContainer()


@implementer(interfaces.IQuizContainer)
@adapter(ISchoolToolApplication)
def getApplicationQuizContainer(app):
    return app[APP_QUIZCONTAINER_KEY]
