#
# SchoolTool - common information systems platform for school administration
# Copyright (c) 2013 Shuttleworth Foundation,
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License along
# with this program; if not, write to the Free Software Foundation, Inc.,
# 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
#
"""
SchoolTool Quiz image.
"""

from persistent import Persistent
from zope.component import adapter
from zope.container.btree import BTreeContainer
from zope.container.contained import Contained
from zope.interface import implements, implementer

from schooltool.app.app import InitBase, StartUpBase
from schooltool.app.interfaces import ISchoolToolApplication
from schooltool.relationship import RelationshipProperty

from schooltool.quiz import interfaces
from schooltool.quiz import relationships


APP_QUIZIMAGECONTAINER_KEY = 'schooltool.quiz.quiz_image'


class QuizImageContainer(BTreeContainer):

    implements(interfaces.IQuizImageContainer)


class QuizImage(Persistent, Contained):

    implements(interfaces.IQuizImage)

    title = None
    contents = None

    items = RelationshipProperty(relationships.URIQuizItemImages,
                                  relationships.URIQuizImage,
                                  relationships.URIQuizItem)

    editors = RelationshipProperty(relationships.URIQuizImageEditors,
                                   relationships.URIQuizImage,
                                   relationships.URIQuizImageEditor)


class QuizImageContainerInit(InitBase):

    def __call__(self):
        self.app[APP_QUIZIMAGECONTAINER_KEY] = QuizImageContainer()


class QuizImageContainerAppStartup(StartUpBase):

    def __call__(self):
        if APP_QUIZIMAGECONTAINER_KEY not in self.app:
            container = QuizImageContainer()
            self.app[APP_QUIZIMAGECONTAINER_KEY] = container


@implementer(interfaces.IQuizImageContainer)
@adapter(ISchoolToolApplication)
def getApplicationQuizImageContainer(app):
    return app[APP_QUIZIMAGECONTAINER_KEY]
