#
# SchoolTool - common information systems platform for school administration
# Copyright (c) 2012 Shuttleworth Foundation,
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License along
# with this program; if not, write to the Free Software Foundation, Inc.,
# 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
#
"""
SchoolTool Quiz docutils components.
"""

from docutils.writers.html4css1 import HTMLTranslator
from docutils.writers.html4css1 import Writer


class QuizHTMLTranslator(HTMLTranslator):

    def __init__(self, document, app_root_url, app_root_pattern):
        self.app_root_url = app_root_url
        self.app_root_pattern = app_root_pattern
        HTMLTranslator.__init__(self, document)

    def fixSRC(self, src):
        return src.replace(self.app_root_pattern, self.app_root_url)

    def starttag(self, node, tagname, suffix='\n', empty=False, **attributes):
        if (tagname == 'img' and
            attributes.get('src', '').startswith(self.app_root_pattern)):
            attributes['src'] = self.fixSRC(attributes['src'])
        return HTMLTranslator.starttag(
            self, node, tagname, suffix, empty, **attributes)


class QuizHTMLWriter(Writer):

    def __init__(self, app_root_url, app_root_pattern):
        Writer.__init__(self)
        self.app_root_url = app_root_url
        self.app_root_pattern = app_root_pattern
        self.translator_class = QuizHTMLTranslator

    def translate(self):
        self.visitor = visitor = self.translator_class(
            self.document, self.app_root_url, self.app_root_pattern)
        self.document.walkabout(visitor)
        for attr in self.visitor_attributes:
            setattr(self, attr, getattr(visitor, attr))
        self.output = self.apply_template()
