#
# SchoolTool - common information systems platform for school administration
# Copyright (c) 2012 Shuttleworth Foundation
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
#
"""
Selenium Functional Testing Utilities for schooltool.quiz.
"""
import os

from schooltool.testing.selenium import SeleniumLayer


dir = os.path.abspath(os.path.dirname(__file__))
filename = os.path.join(dir, 'stesting.zcml')
quiz_selenium_layer = SeleniumLayer(filename,
                                    __name__,
                                    'quiz_selenium_layer')


def registerSeleniumSetup():
    try:
        import selenium
    except ImportError:
        return
    from schooltool.testing import registry
    import schooltool.testing.selenium

    def addEditors(browser, quiz_id, editors):
        # XXX: use quiz title instead of quiz_id here
        browser.open('http://localhost/quizzes/%s' % quiz_id)
        browser.query.link('Grant Access').click()
        selector = 'available_table-ajax-available_table--title'
        browser.query.id(selector).type(', '.join(editors))
        selector = '#available_table-ajax-available_table- table'
        table = browser.query.css(selector)
        browser.query.name('SEARCH_BUTTON').click()
        browser.wait(lambda: table.expired)
        # XXX: Click Show All here in case there are lots of people
        selector = '#available_table-ajax-available_table- table'
        table = browser.query.css(selector)
        browser.query.name('ADD_DISPLAYED_RESULTS').click()
        browser.wait(lambda: table.expired)

    registry.register('SeleniumHelpers',
        lambda: schooltool.testing.selenium.registerBrowserUI(
            'quiz.editors.add', addEditors))

    def removeEditors(browser, quiz_id, editors):
        browser.open('http://localhost/quizzes/%s' % quiz_id)
        browser.query.link('Grant Access').click()
        # XXX: Click Show All here in case there are lots of people
        for editor in editors:
            selector = '#current_table-ajax-current_table- table'
            table = browser.query.css(selector)
            selector = '//button[@name="remove_item.%s"]' % editor
            browser.query.xpath(selector).click()
            browser.wait(lambda: table.expired)

    registry.register('SeleniumHelpers',
        lambda: schooltool.testing.selenium.registerBrowserUI(
            'quiz.editors.remove', removeEditors))

    def addQuiz(browser, QuizName):
        browser.open('http://localhost/quizzes/add.html') 
        browser.query.name('form.widgets.title').type(QuizName)
        browser.query.button('Submit').click()
    
    registry.register('SeleniumHelpers',
        lambda: schooltool.testing.selenium.registerBrowserUI(
             'quiz.addQuiz', addQuiz))

    def addOpenQuestionToCurrentQuiz(browser, Body, Solution ):
        browser.query.link('Question').click()
        browser.query.id("form-widgets-type_-2").click()
        browser.query.name('form.widgets.body').type(Body)
        browser.query.name('form.widgets.solution').type(Solution)
        browser.query.button('Submit').click()
    
    registry.register('SeleniumHelpers',
        lambda: schooltool.testing.selenium.registerBrowserUI(
              'quiz.addOpenQuestion', addOpenQuestionToCurrentQuiz))


    def addSelectionQuestionToCurrentQuiz(browser, Body, Choices, Course, Skill):
        browser.query.link('Question').click()
        browser.query.id("form-widgets-type_-0").click()
        browser.query.name('form.widgets.body').type(Body)
        i = 0
        for choice in Choices:
            browser.query.id("form-widgets-choices-buttons-add").click()
            browser.query.id("form-widgets-choices-{0}-widgets-body".format(i)).type(choice[0])
            if choice[1]:
                browser.query.id("form-widgets-choices-{0}-widgets-correct-0".format(i)).click()
            i+=1
        browser.query.id("form-widgets-course-{0}".format(Course)).click()
        browser.query.id("form-widgets-skill-{0}".format(Skill)).click()
        browser.query.button('Submit').click()
   
    registry.register('SeleniumHelpers',
        lambda: schooltool.testing.selenium.registerBrowserUI(
              'quiz.addSelectionQuestion', addSelectionQuestionToCurrentQuiz))


    def deployQuizFromCurrentQuiz(browser, Section, SubmitTo, Sheet, Title=None, Random=False):
        browser.query.link("Deploy").click()
        browser.query.id("form-widgets-section-{0}".format(Section)).click()
        browser.query.id("form-widgets-deployment_type-{0}".format(SubmitTo)).click()
        worksheets = browser.query_all.css('option[id^="form-widgets-worksheet-"]')
        if worksheets:
            worksheets[Sheet].click()
        if Title is not None:
            browser.query.id("form-widgets-title").type(Title)
        if Random: 
            browser.query.id("form-widgets-random-0").click()
        browser.query.button('Submit').click()
        browser.query.link('Open').click()


    registry.register('SeleniumHelpers',
        lambda: schooltool.testing.selenium.registerBrowserUI(
              'quiz.deployQuiz', deployQuizFromCurrentQuiz))

registerSeleniumSetup()
del registerSeleniumSetup
