#
# SchoolTool - common information systems platform for school administration
# Copyright (c) 2012 Shuttleworth Foundation,
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License along
# with this program; if not, write to the Free Software Foundation, Inc.,
# 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
#
"""
SchoolTool Quiz utility functions.
"""

from cgi import escape
from docutils.core import publish_parts

from zope.traversing.browser.absoluteurl import absoluteURL

from schooltool.app.interfaces import ISchoolToolApplication

from schooltool.quiz import QuizMessage as _
from schooltool.quiz.rst import QuizHTMLWriter


APP_ROOT_PATTERN = '**quiz-images-root**'
# XXX: customize and use IApplicationPreferences for this
DATETIME_FORMAT = _('YYYY-MM-DD HH:MM:SS')
DATETIME_INPUT_FORMAT = '%Y-%m-%d %H:%M:%S'
DATE_FORMAT = _('YYYY-MM-DD')
DATE_INPUT_FORMAT = '%Y-%m-%d'


def render_rst(rst, request):
    app = ISchoolToolApplication(None)
    # XXX: sanitize before rendering
    settings_overrides={
        'math_output': 'mathjax',
        }
    parts = publish_parts(
        rst,
        writer=QuizHTMLWriter(absoluteURL(app, request), APP_ROOT_PATTERN),
        settings_overrides=settings_overrides)
    return parts['body']


def render_pre(text):
    return '<pre>%s</pre>' % escape(text)


def render_datetime(value):
    return value.strftime(DATETIME_INPUT_FORMAT)


def render_date(value):
    return value.strftime(DATE_INPUT_FORMAT)


def render_bool(value):
    return [_('No'), _('Yes')][value]


def format_percentage(number):
    return '%.0f%%' % number
